==> ec2-1.0.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnCustomerGatewayProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::CustomerGateway`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.0 (build a586a1a)", date = "2019-07-11T14:13:21.569Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnCustomerGatewayProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::CustomerGateway.BgpAsn`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-bgpasn
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Number getBgpAsn();
    /**
     * `AWS::EC2::CustomerGateway.IpAddress`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-ipaddress
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getIpAddress();
    /**
     * `AWS::EC2::CustomerGateway.Type`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-type
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getType();
    /**
     * `AWS::EC2::CustomerGateway.Tags`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.util.List<software.amazon.awscdk.core.CfnTag> getTags();

    /**
     * @return a {@link Builder} of {@link CfnCustomerGatewayProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnCustomerGatewayProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.lang.Number _bgpAsn;
        private java.lang.String _ipAddress;
        private java.lang.String _type;
        @javax.annotation.Nullable
        private java.util.List<software.amazon.awscdk.core.CfnTag> _tags;

        /**
         * Sets the value of BgpAsn
         * @param value `AWS::EC2::CustomerGateway.BgpAsn`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withBgpAsn(final java.lang.Number value) {
            this._bgpAsn = java.util.Objects.requireNonNull(value, "bgpAsn is required");
            return this;
        }
        /**
         * Sets the value of IpAddress
         * @param value `AWS::EC2::CustomerGateway.IpAddress`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withIpAddress(final java.lang.String value) {
            this._ipAddress = java.util.Objects.requireNonNull(value, "ipAddress is required");
            return this;
        }
        /**
         * Sets the value of Type
         * @param value `AWS::EC2::CustomerGateway.Type`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withType(final java.lang.String value) {
            this._type = java.util.Objects.requireNonNull(value, "type is required");
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value `AWS::EC2::CustomerGateway.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withTags(@javax.annotation.Nullable final java.util.List<software.amazon.awscdk.core.CfnTag> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCustomerGatewayProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnCustomerGatewayProps build() {
            return new CfnCustomerGatewayProps() {
                private final java.lang.Number $bgpAsn = java.util.Objects.requireNonNull(_bgpAsn, "bgpAsn is required");
                private final java.lang.String $ipAddress = java.util.Objects.requireNonNull(_ipAddress, "ipAddress is required");
                private final java.lang.String $type = java.util.Objects.requireNonNull(_type, "type is required");
                @javax.annotation.Nullable
                private final java.util.List<software.amazon.awscdk.core.CfnTag> $tags = _tags;

                @Override
                public java.lang.Number getBgpAsn() {
                    return this.$bgpAsn;
                }

                @Override
                public java.lang.String getIpAddress() {
                    return this.$ipAddress;
                }

                @Override
                public java.lang.String getType() {
                    return this.$type;
                }

                @Override
                public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
                    return this.$tags;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("bgpAsn", om.valueToTree(this.getBgpAsn()));
                    obj.set("ipAddress", om.valueToTree(this.getIpAddress()));
                    obj.set("type", om.valueToTree(this.getType()));
                    if (this.getTags() != null) {
                        obj.set("tags", om.valueToTree(this.getTags()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnCustomerGatewayProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::EC2::CustomerGateway.BgpAsn`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-bgpasn
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.Number getBgpAsn() {
            return this.jsiiGet("bgpAsn", java.lang.Number.class);
        }

        /**
         * `AWS::EC2::CustomerGateway.IpAddress`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-ipaddress
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getIpAddress() {
            return this.jsiiGet("ipAddress", java.lang.String.class);
        }

        /**
         * `AWS::EC2::CustomerGateway.Type`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-type
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getType() {
            return this.jsiiGet("type", java.lang.String.class);
        }

        /**
         * `AWS::EC2::CustomerGateway.Tags`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-tags
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.jsiiGet("tags", java.util.List.class);
        }
    }
}

==> ec2-1.1.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnCustomerGatewayProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::CustomerGateway`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.2 (build e881f16)", date = "2019-07-19T19:06:47.490Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnCustomerGatewayProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::CustomerGateway.BgpAsn`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-bgpasn
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Number getBgpAsn();
    /**
     * `AWS::EC2::CustomerGateway.IpAddress`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-ipaddress
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getIpAddress();
    /**
     * `AWS::EC2::CustomerGateway.Type`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-type
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getType();
    /**
     * `AWS::EC2::CustomerGateway.Tags`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<software.amazon.awscdk.core.CfnTag> getTags();

    /**
     * @return a {@link Builder} of {@link CfnCustomerGatewayProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnCustomerGatewayProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.lang.Number _bgpAsn;
        private java.lang.String _ipAddress;
        private java.lang.String _type;
        @javax.annotation.Nullable
        private java.util.List<software.amazon.awscdk.core.CfnTag> _tags;

        /**
         * Sets the value of BgpAsn
         * @param value `AWS::EC2::CustomerGateway.BgpAsn`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withBgpAsn(final java.lang.Number value) {
            this._bgpAsn = java.util.Objects.requireNonNull(value, "bgpAsn is required");
            return this;
        }
        /**
         * Sets the value of IpAddress
         * @param value `AWS::EC2::CustomerGateway.IpAddress`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withIpAddress(final java.lang.String value) {
            this._ipAddress = java.util.Objects.requireNonNull(value, "ipAddress is required");
            return this;
        }
        /**
         * Sets the value of Type
         * @param value `AWS::EC2::CustomerGateway.Type`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withType(final java.lang.String value) {
            this._type = java.util.Objects.requireNonNull(value, "type is required");
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value `AWS::EC2::CustomerGateway.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withTags(@javax.annotation.Nullable final java.util.List<software.amazon.awscdk.core.CfnTag> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCustomerGatewayProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnCustomerGatewayProps build() {
            return new CfnCustomerGatewayProps() {
                private final java.lang.Number $bgpAsn = java.util.Objects.requireNonNull(_bgpAsn, "bgpAsn is required");
                private final java.lang.String $ipAddress = java.util.Objects.requireNonNull(_ipAddress, "ipAddress is required");
                private final java.lang.String $type = java.util.Objects.requireNonNull(_type, "type is required");
                @javax.annotation.Nullable
                private final java.util.List<software.amazon.awscdk.core.CfnTag> $tags = _tags;

                @Override
                public java.lang.Number getBgpAsn() {
                    return this.$bgpAsn;
                }

                @Override
                public java.lang.String getIpAddress() {
                    return this.$ipAddress;
                }

                @Override
                public java.lang.String getType() {
                    return this.$type;
                }

                @Override
                public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
                    return this.$tags;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("bgpAsn", om.valueToTree(this.getBgpAsn()));
                    obj.set("ipAddress", om.valueToTree(this.getIpAddress()));
                    obj.set("type", om.valueToTree(this.getType()));
                    if (this.getTags() != null) {
                        obj.set("tags", om.valueToTree(this.getTags()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnCustomerGatewayProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::EC2::CustomerGateway.BgpAsn`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-bgpasn
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.Number getBgpAsn() {
            return this.jsiiGet("bgpAsn", java.lang.Number.class);
        }

        /**
         * `AWS::EC2::CustomerGateway.IpAddress`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-ipaddress
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getIpAddress() {
            return this.jsiiGet("ipAddress", java.lang.String.class);
        }

        /**
         * `AWS::EC2::CustomerGateway.Type`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-type
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getType() {
            return this.jsiiGet("type", java.lang.String.class);
        }

        /**
         * `AWS::EC2::CustomerGateway.Tags`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-customer-gateway.html#cfn-ec2-customergateway-tags
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.jsiiGet("tags", java.util.List.class);
        }
    }
}
